==> mew_6.5.orig.tar.gz: mew-6.5/auxiliary.el <==
(defvar FLD-MSG-LIST nil)
(defvar ange-ftp-generate-anonymous-password nil)
(defvar ange-ftp-tmp-name-template nil)
(defvar auto-image-file-mode nil)
(defvar coding-category-list nil)
(defvar current-menubar nil)
(defvar default-file-name-coding-system nil)
(defvar default-process-argument-editing-function nil)
(defvar dnd-protocol-alist nil)
(defvar elp-function-list nil)
(defvar elp-results-buffer nil)
(defvar exec-suffixes nil)
(defvar find-file-hook nil)
(defvar inhibit-eol-conversion nil)
(defvar inhibit-point-motion-hooks nil)
(defvar jka-compr-inhibit nil)
(defvar large-file-warning-threshold nil)
(defvar last-pressed-toolbar-button nil)
(defvar longlines-mode nil)
(defvar mark-active nil)
(defvar max-mini-window-height nil)
(defvar mew-draft-toolbar nil)
(defvar mew-message-toolbar nil)
(defvar mew-summary-toolbar nil)
(defvar mode-line-position nil)
(defvar mule-version nil)
(defvar process-argument-editing-alist nil)
(defvar profile-buffer nil)
(defvar profile-functions-list nil)
(defvar scrollbar-height nil)
(defvar system-name nil)
(defvar system-time-locale nil)
(defvar toolbar-active nil)
(defvar toolbar-map nil)
(defvar transient-mark-mode nil)
(defvar w32-get-true-file-link-count nil)
(defvar w32-start-process-show-window nil)
(defvar w3m-content-type-alist nil)
(defvar write-region-inhibit-fsync nil)
(defvar x-dnd-test-function nil)

(defun add-submenu (&rest args))
(defun amultibyte-string-p (&rest args))
(defun ange-ftp-copy-file-internal (&rest args))
(defun ange-ftp-expand-file-name (&rest args))
(defun ange-ftp-file-name-all-completions (&rest args))
(defun ange-ftp-file-name-completion (&rest args))
(defun bitmap-insert-xbm-file (&rest args))
(defun charset-priority-list (&rest args))
(defun create-image (&rest args))
(defun define-process-argument-editing (&rest args))
(defun delete-overlay (&rest args))
(defun display-graphic-p (&rest args))
(defun dnd-get-local-file-name (&rest args))
(defun dnd-get-local-file-uri (&rest args))
(defun dos-to-unix-filename (&rest args))
(defun event-start (&rest args))
(defun fill-match-adaptive-prefix (&rest args))
(defun find-image (&rest args))
(defun general-process-argument-editing-function (&rest args))
(defun image-size (&rest args))
(defun image-type-available-p (&rest args))
(defun image-type-available-p (&rest args))
(defun insert-image (&rest args))
(defun jit-lock-register (&rest args))
(defun longlines-mode (&rest args))
(defun mac-set-file-type (&rest args))
(defun make-network-process (&rest args))
(defun make-overlay (&rest args))
(defun message-box (&rest args))
(defun mew-hscroll (&rest args))
(defun minibuffer-prompt-end (&rest args))
(defun mouse-set-point (&rest args))
(defun move-overlay (&rest args))
(defun multibyte-string-p (&rest args))
(defun mw32script-argument-editing-function (&rest args))
(defun mw32script-init (&rest args))
(defun mw32script-make-pathext-regexp (&rest args))
(defun mw32script-openp (&rest args))
(defun mw32script-resolve-script (&rest args))
(defun overlay-get (&rest args))
(defun overlay-put (&rest args))
(defun overlayp (&rest args))
(defun overlays-in (&rest args))
(defun popup-menu (&rest args))
(defun posn-window (&rest args))
(defun profile-functions (&rest args))
(defun propertize (&rest args))
(defun propertized-buffer-identification (&rest args))
(defun remove-images (&rest args))
(defun set-buffer-menubar (&rest args))
(defun set-buffer-multibyte (&rest args))
(defun set-charset-priority (&rest args))
(defun set-coding-priority (&rest args))
(defun set-process-query-on-exit-flag (&rest args))
(defun set-toolbar-button-down-flag (&rest args))
(defun string-as-multibyte (&rest args))
(defun string-as-unibyte (&rest args))
(defun tool-bar-add-item-from-menu (&rest args))
(defun tool-bar-local-item-from-menu (&rest args))
(defun toolbar-button-callback (&rest args))
(defun toolbar-button-enabled-p (&rest args))
(defun toolbar-button-help-string (&rest args))
(defun toolbar-make-button-list (&rest args))
(defun update-coding-systems-internal (&rest args))
(defun w32-focus-frame (&rest args))
(defun w3m-expand-file-name-as-url (&rest args))
(defun w3m-region (&rest args))
(defun w3m-url-local-p (&rest args))
(defun w3m-url-to-file-name (&rest args))
(defun window-edges (&rest args))
(defun x-dnd-choose-type (&rest args))

(require 'mew-lang-jp)
(require 'mew-lang-latin)

==> mew_6.7.orig.tar.gz: mew-6.7/auxiliary.el <==
(defvar FLD-MSG-LIST nil)
(defvar ange-ftp-generate-anonymous-password nil)
(defvar ange-ftp-tmp-name-template nil)
(defvar auto-image-file-mode nil)
(defvar bidi-paragraph-direction nil)
(defvar coding-category-list nil)
(defvar current-menubar nil)
(defvar default-file-name-coding-system nil)
(defvar default-process-argument-editing-function nil)
(defvar display-buffer-alist nil)
(defvar dnd-protocol-alist nil)
(defvar elp-function-list nil)
(defvar elp-results-buffer nil)
(defvar exec-suffixes nil)
(defvar find-file-hook nil)
(defvar inhibit-eol-conversion nil)
(defvar inhibit-point-motion-hooks nil)
(defvar jka-compr-inhibit nil)
(defvar large-file-warning-threshold nil)
(defvar last-pressed-toolbar-button nil)
(defvar longlines-mode nil)
(defvar mark-active nil)
(defvar max-mini-window-height nil)
(defvar mew-draft-toolbar nil)
(defvar mew-message-toolbar nil)
(defvar mew-summary-toolbar nil)
(defvar mode-line-position nil)
(defvar mule-version nil)
(defvar process-argument-editing-alist nil)
(defvar profile-buffer nil)
(defvar profile-functions-list nil)
(defvar scrollbar-height nil)
(defvar system-name nil)
(defvar system-time-locale nil)
(defvar toolbar-active nil)
(defvar toolbar-map nil)
(defvar transient-mark-mode nil)
(defvar visual-line-mode nil)
(defvar w32-get-true-file-link-count nil)
(defvar w32-start-process-show-window nil)
(defvar w3m-content-type-alist nil)
(defvar write-region-inhibit-fsync nil)
(defvar x-dnd-test-function nil)

(defun add-submenu (&rest args))
(defun amultibyte-string-p (&rest args))
(defun ange-ftp-copy-file-internal (&rest args))
(defun ange-ftp-expand-file-name (&rest args))
(defun ange-ftp-file-name-all-completions (&rest args))
(defun ange-ftp-file-name-completion (&rest args))
(defun bitmap-insert-xbm-file (&rest args))
(defun called-interactively-p (&rest args))
(defun charset-priority-list (&rest args))
(defun coding-system-equal(&rest args))
(defun create-image (&rest args))
(defun define-process-argument-editing (&rest args))
(defun delete-overlay (&rest args))
(defun display-graphic-p (&rest args))
(defun dnd-get-local-file-name (&rest args))
(defun dnd-get-local-file-uri (&rest args))
(defun dos-to-unix-filename (&rest args))
(defun event-start (&rest args))
(defun fill-match-adaptive-prefix (&rest args))
(defun find-image (&rest args))
(defun general-process-argument-editing-function (&rest args))
(defun image-size (&rest args))
(defun image-type-available-p (&rest args))
(defun insert-image (&rest args))
(defun jit-lock-register (&rest args))
(defun longlines-mode (&rest args))
(defun mac-set-file-type (&rest args))
(defun make-network-process (&rest args))
(defun make-overlay (&rest args))
(defun message-box (&rest args))
(defun mew-ext-copy-file-internal (&rest args))
(defun mew-ext-expand-dir (&rest args))
(defun mew-hscroll (&rest args))
(defun minibuffer-prompt-end (&rest args))
(defun mouse-set-point (&rest args))
(defun move-overlay (&rest args))
(defun multibyte-string-p (&rest args))
(defun mw32script-argument-editing-function (&rest args))
(defun mw32script-init (&rest args))
(defun mw32script-make-pathext-regexp (&rest args))
(defun mw32script-openp (&rest args))
(defun mw32script-resolve-script (&rest args))
(defun overlay-get (&rest args))
(defun overlay-put (&rest args))
(defun overlayp (&rest args))
(defun overlays-in (&rest args))
(defun popup-menu (&rest args))
(defun posn-window (&rest args))
(defun profile-functions (&rest args))
(defun propertize (&rest args))
(defun propertized-buffer-identification (&rest args))
(defun remove-images (&rest args))
(defun set-buffer-menubar (&rest args))
(defun set-buffer-multibyte (&rest args))
(defun set-charset-priority (&rest args))
(defun set-coding-priority (&rest args))
(defun set-process-query-on-exit-flag (&rest args))
(defun set-toolbar-button-down-flag (&rest args))
(defun string-as-multibyte (&rest args))
(defun string-as-unibyte (&rest args))
(defun tool-bar-add-item-from-menu (&rest args))
(defun tool-bar-local-item-from-menu (&rest args))
(defun toolbar-button-callback (&rest args))
(defun toolbar-button-enabled-p (&rest args))
(defun toolbar-button-help-string (&rest args))
(defun toolbar-make-button-list (&rest args))
(defun update-coding-systems-internal (&rest args))
(defun visual-line-mode (&rest args))
(defun w32-focus-frame (&rest args))
(defun w3m-expand-file-name-as-url (&rest args))
(defun w3m-region (&rest args))
(defun w3m-url-local-p (&rest args))
(defun w3m-url-to-file-name (&rest args))
(defun window-edges (&rest args))
(defun x-dnd-choose-type (&rest args))

(require 'mew-lang-jp)
(require 'mew-lang-latin)
